# pytdt
[![PyPI version](https://badge.fury.io/py/pytdt.svg)](https://badge.fury.io/py/pytdt)

A tool for interfacing with and reading TDT blocks in python

## Installation

`pip install pytdt`

## Usage

```
>>> import pytdt

>>> block = pytdt.Block('path/to/block')
>>> block.read_streams()
```

## Documentation

[Read the docs here](https://logangrado.github.io/pytdt/)
